pub struct RouteMapping { /* private fields */ }Expand description
Configuration for mapping OpenAPI operations to MCP components.
Implementations
Sourceimpl RouteMapping
impl RouteMapping
Sourcepub fn default_rules() -> Self
pub fn default_rules() -> Self
Create default mapping rules:
- GET → Resource
- POST, PUT, PATCH, DELETE → Tool
Sourcepub fn map_methods<I, S>(self, methods: I, mcp_type: McpType) -> Self
pub fn map_methods<I, S>(self, methods: I, mcp_type: McpType) -> Self
Add a rule to map specific HTTP methods to an MCP type.
Sourcepub fn map_method(self, method: &str, mcp_type: McpType) -> Self
pub fn map_method(self, method: &str, mcp_type: McpType) -> Self
Add a rule to map a specific HTTP method to an MCP type.
Sourcepub fn map_pattern(self, pattern: &str, mcp_type: McpType) -> Result<Self>
pub fn map_pattern(self, pattern: &str, mcp_type: McpType) -> Result<Self>
Add a rule to map paths matching a pattern to an MCP type.
Sourcepub fn map_rule<I, S>(
self,
methods: I,
pattern: &str,
mcp_type: McpType,
priority: i32,
) -> Result<Self>
pub fn map_rule<I, S>( self, methods: I, pattern: &str, mcp_type: McpType, priority: i32, ) -> Result<Self>
Add a rule to map specific methods and pattern to an MCP type.
Sourcepub fn skip_pattern(self, pattern: &str) -> Result<Self>
pub fn skip_pattern(self, pattern: &str) -> Result<Self>
Skip operations matching a pattern.
Sourcepub fn get_mcp_type(&self, method: &str, path: &str) -> McpType
pub fn get_mcp_type(&self, method: &str, path: &str) -> McpType
Determine the MCP type for a given HTTP method and path.
Rules are checked in order of priority (highest first), then insertion order.
Returns McpType::Tool as default if no rule matches.